==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/bmp/skin_tab.gif.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_tab.gif"

unsigned char _mgir_gif_skin_tab_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x12,0x00,	0x48,0x00,0xC6,0x41,0x00,0x35,0x77,0xDF,
	0x35,0x7A,0xE3,0x33,0x7E,0xE7,0x33,0x81,	0xED,0x32,0x87,0xF2,0x30,0x8C,0xFA,0x31,
	0x94,0xFF,0x37,0x99,0xFF,0x87,0x87,0x87,	0x88,0x88,0x88,0x89,0x89,0x89,0x8B,0x8B,
	0x8B,0x3E,0x9D,0xFF,0x8C,0x8C,0x8C,0x8E,	0x8E,0x8E,0x90,0x90,0x90,0x44,0xA5,0xFF,
	0x92,0x92,0x92,0x93,0x93,0x93,0x94,0x94,	0x94,0x4A,0xA9,0xFF,0x97,0x97,0x97,0x98,
	0x98,0x98,0x99,0x99,0x99,0x9A,0x9A,0x9A,	0x9B,0x9B,0x9B,0x51,0xAF,0xFF,0x9C,0x9C,
	0x9C,0x9E,0x9E,0x9E,0x9F,0x9F,0x9F,0x57,	0xB2,0xFF,0x5D,0xB6,0xFF,0x61,0xBA,0xFF,
	0x66,0xBD,0xFF,0x6A,0xBF,0xFF,0x6D,0xC1,	0xFF,0xAF,0xAF,0xAF,0x6E,0xC2,0xFF,0xB0,
	0xB0,0xB0,0xB3,0xB3,0xB3,0xB6,0xB6,0xB6,	0x7F,0xC9,0xFF,0x80,0xC9,0xFF,0xBA,0xBA,
	0xBA,0xBF,0xBF,0xBF,0xC4,0xC4,0xC4,0xC9,	0xC9,0xC9,0xA1,0xD7,0xFF,0xA4,0xD8,0xFF,
	0xCE,0xCE,0xCE,0xCF,0xCF,0xCF,0xD1,0xD1,	0xD1,0xD2,0xD2,0xD2,0xD5,0xD5,0xD5,0xDA,
	0xDA,0xDA,0xE0,0xE0,0xE0,0xE1,0xE1,0xE1,	0xE3,0xE3,0xE3,0xE6,0xE6,0xE6,0xEB,0xEB,
	0xEB,0xF0,0xF0,0xF0,0xF5,0xF5,0xF5,0xF9,	0xF9,0xF9,0xFC,0xFC,0xFC,0xFE,0xFE,0xFE,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0x21,0xFE,0x15,
	0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,	0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,
	0x20,0x47,0x49,0x4D,0x50,0x00,0x2C,0x00,	0x00,0x00,0x00,0x12,0x00,0x48,0x00,0x00,
	0x07,0xFE,0x80,0x33,0x31,0x24,0x1D,0x1C,	0x86,0x87,0x88,0x1D,0x1D,0x26,0x31,0x33,
	0x1B,0x8F,0x90,0x91,0x92,0x1B,0x17,0x33,	0x19,0x97,0x98,0x99,0x9A,0x19,0x17,0x34,
	0x18,0x9F,0xA0,0xA1,0xA2,0x9F,0x33,0xA3,	0xA6,0xA1,0x33,0x16,0xAA,0xAB,0xAC,0xAD,
	0xAA,0x33,0x15,0xB1,0xB2,0xB3,0xB4,0xB1,	0x33,0x13,0xB8,0xB9,0xBA,0xBB,0xB8,0x33,
	0x12,0xBF,0xC0,0xC1,0xC2,0xBF,0x34,0x11,	0xC6,0xC7,0xC8,0xC9,0xC6,0x33,0x0F,0xCD,
	0xCE,0xCF,0xD0,0xCD,0x33,0x0E,0xD4,0xD5,	0xD6,0xD7,0xD4,0x33,0x0D,0xDB,0xDC,0xDD,
	0xDE,0xDB,0x33,0x0B,0xE2,0xE3,0xE4,0xE5,	0xE2,0xE1,0xE6,0xE9,0xE3,0x34,0x0A,0xED,
	0xEE,0xEF,0xF0,0xED,0x33,0x09,0xF4,0xF5,	0xF6,0xF7,0xF4,0x33,0x08,0xFB,0xFC,0xFD,
	0xFE,0xFB,0x33,0x60,0xA8,0x28,0x31,0xA2,	0xA0,0xC1,0x83,0x25,0x4A,0xA4,0x78,0x31,
	0x43,0x84,0xC3,0x87,0x10,0x23,0x3A,0x9C,	0x11,0xA2,0xA2,0xC5,0x8B,0x18,0x2B,0xD2,
	0x00,0xC1,0xB1,0xA3,0xC7,0x8F,0x1C,0x67,	0x7C,0x18,0x49,0xB2,0xA4,0xC9,0x91,0x33,
	0x3C,0xA8,0x5C,0xC9,0xB2,0xA5,0xCA,0x19,	0x1A,0x62,0xCA,0x9C,0x49,0x33,0xE6,0x0C,
	0x0A,0x38,0x73,0xEA,0xDC,0x89,0x73,0x06,	0x84,0x9F,0x40,0x83,0x0A,0xFD,0x49,0x83,
	0x81,0xD1,0xA3,0x48,0x93,0x1A,0x9D,0x71,	0xA0,0xA9,0xD3,0xA7,0x50,0x9B,0xCE,0x30,
	0x40,0xB5,0xAA,0xD5,0xAB,0x54,0x67,0x14,	0xD8,0xCA,0xB5,0xAB,0xD7,0xAD,0x33,0x08,
	0x88,0x1D,0x4B,0xB6,0xAC,0xD8,0x19,0x03,	0xD2,0xAA,0x5D,0xCB,0x36,0x2D,0x0D,0x01,
	0xFE,0x70,0xE3,0xCA,0x9D,0x0B,0x77,0x46,	0x80,0xBB,0x78,0xF3,0xEA,0xBD,0x3B,0x03,
	0x80,0xDF,0xBF,0x80,0x03,0xFB,0x0D,0x38,	0xF0,0xA0,0xE1,0x11,0x09,0x17,0x36,0x94,
	0xC8,0xF8,0x21,0xC5,0x8C,0x90,0x2D,0x6E,	0x04,0x49,0xB9,0xA3,0xC8,0x93,0x98,0x49,
	0xA6,0x74,0xC9,0x79,0x25,0xCC,0x9A,0xA0,	0x65,0xDE,0xE4,0x49,0x3A,0xA7,0xCF,0xA1,
	0xA8,0x81,0x16,0x55,0xCA,0xFA,0x28,0xD3,	0xA8,0xB0,0x9D,0x4E,0xC5,0x4A,0xBB,0xAA,
	0xD6,0xAF,0xB8,0xB9,0x86,0x35,0xCB,0x7B,	0x2C,0xDA,0xB6,0xC0,0xD5,0xBE,0xA5,0x4B,
	0x3C,0xAE,0xDD,0xBD,0xC8,0xF1,0xF6,0x15,	0xCC,0xFC,0xEF,0x0C,0x1C,0x3D,0x80,0x04,
	0x99,0x4E,0xBD,0xBA,0xF4,0x1E,0x39,0x66,	0xFC,0xD8,0xCE,0xBD,0xBB,0xF7,0x1F,0x3E,
	0x66,0xF8,0x18,0x4F,0xBE,0xBC,0xF9,0xF1,	0x34,0x7A,0xA8,0x5F,0xCF,0xBE,0xBD,0xFA,
	0x19,0x3C,0xE2,0xCB,0x9F,0x4F,0x3F,0xFE,	0x8C,0x1D,0xF8,0xF3,0xEB,0xDF,0x8F,0x7F,
	0x86,0x8E,0xFF,0x00,0x06,0x28,0xE0,0x7F,	0x33,0xDC,0x60,0xE0,0x81,0x08,0x26,0x68,
	0xE0,0x0C,0x36,0x34,0xE8,0xE0,0x83,0x10,	0x36,0x48,0x43,0x0D,0x14,0x56,0x68,0xE1,
	0x85,0x14,0xCE,0x20,0xC3,0x86,0x1C,0x76,	0xE8,0xE1,0x86,0x33,0xB8,0x20,0xE2,0x88,
	0x24,0x96,0x28,0xE2,0x0C,0x2D,0xA4,0xA8,	0xE2,0x8A,0x2C,0xA6,0x38,0x03,0x0B,0x30,
	0xC6,0x28,0xE3,0x8C,0x30,0xCE,0xB0,0xC2,	0x8D,0x38,0xE6,0xA8,0xE3,0x8D,0x34,0xA0,
	0xE0,0xE3,0x8F,0x40,0x06,0xE9,0xE3,0x0C,	0x27,0x14,0x69,0xE4,0x91,0x48,0x16,0x0B,
	0x39,0x83,0x09,0x4C,0x36,0xE9,0xE4,0x93,	0x4C,0x06,0x02,0x00,0x3B
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/bmp/skin_tab.gif.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_tab.gif"

const unsigned char _mgir_gif_skin_tab_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x12,0x00,	0x48,0x00,0xC6,0x41,0x00,0x35,0x77,0xDF,
	0x35,0x7A,0xE3,0x33,0x7E,0xE7,0x33,0x81,	0xED,0x32,0x87,0xF2,0x30,0x8C,0xFA,0x31,
	0x94,0xFF,0x37,0x99,0xFF,0x87,0x87,0x87,	0x88,0x88,0x88,0x89,0x89,0x89,0x8B,0x8B,
	0x8B,0x3E,0x9D,0xFF,0x8C,0x8C,0x8C,0x8E,	0x8E,0x8E,0x90,0x90,0x90,0x44,0xA5,0xFF,
	0x92,0x92,0x92,0x93,0x93,0x93,0x94,0x94,	0x94,0x4A,0xA9,0xFF,0x97,0x97,0x97,0x98,
	0x98,0x98,0x99,0x99,0x99,0x9A,0x9A,0x9A,	0x9B,0x9B,0x9B,0x51,0xAF,0xFF,0x9C,0x9C,
	0x9C,0x9E,0x9E,0x9E,0x9F,0x9F,0x9F,0x57,	0xB2,0xFF,0x5D,0xB6,0xFF,0x61,0xBA,0xFF,
	0x66,0xBD,0xFF,0x6A,0xBF,0xFF,0x6D,0xC1,	0xFF,0xAF,0xAF,0xAF,0x6E,0xC2,0xFF,0xB0,
	0xB0,0xB0,0xB3,0xB3,0xB3,0xB6,0xB6,0xB6,	0x7F,0xC9,0xFF,0x80,0xC9,0xFF,0xBA,0xBA,
	0xBA,0xBF,0xBF,0xBF,0xC4,0xC4,0xC4,0xC9,	0xC9,0xC9,0xA1,0xD7,0xFF,0xA4,0xD8,0xFF,
	0xCE,0xCE,0xCE,0xCF,0xCF,0xCF,0xD1,0xD1,	0xD1,0xD2,0xD2,0xD2,0xD5,0xD5,0xD5,0xDA,
	0xDA,0xDA,0xE0,0xE0,0xE0,0xE1,0xE1,0xE1,	0xE3,0xE3,0xE3,0xE6,0xE6,0xE6,0xEB,0xEB,
	0xEB,0xF0,0xF0,0xF0,0xF5,0xF5,0xF5,0xF9,	0xF9,0xF9,0xFC,0xFC,0xFC,0xFE,0xFE,0xFE,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0x21,0xFE,0x15,
	0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,	0x77,0x69,0x74,0x68,0x20,0x54,0x68,0x65,
	0x20,0x47,0x49,0x4D,0x50,0x00,0x2C,0x00,	0x00,0x00,0x00,0x12,0x00,0x48,0x00,0x00,
	0x07,0xFE,0x80,0x33,0x31,0x24,0x1D,0x1C,	0x86,0x87,0x88,0x1D,0x1D,0x26,0x31,0x33,
	0x1B,0x8F,0x90,0x91,0x92,0x1B,0x17,0x33,	0x19,0x97,0x98,0x99,0x9A,0x19,0x17,0x34,
	0x18,0x9F,0xA0,0xA1,0xA2,0x9F,0x33,0xA3,	0xA6,0xA1,0x33,0x16,0xAA,0xAB,0xAC,0xAD,
	0xAA,0x33,0x15,0xB1,0xB2,0xB3,0xB4,0xB1,	0x33,0x13,0xB8,0xB9,0xBA,0xBB,0xB8,0x33,
	0x12,0xBF,0xC0,0xC1,0xC2,0xBF,0x34,0x11,	0xC6,0xC7,0xC8,0xC9,0xC6,0x33,0x0F,0xCD,
	0xCE,0xCF,0xD0,0xCD,0x33,0x0E,0xD4,0xD5,	0xD6,0xD7,0xD4,0x33,0x0D,0xDB,0xDC,0xDD,
	0xDE,0xDB,0x33,0x0B,0xE2,0xE3,0xE4,0xE5,	0xE2,0xE1,0xE6,0xE9,0xE3,0x34,0x0A,0xED,
	0xEE,0xEF,0xF0,0xED,0x33,0x09,0xF4,0xF5,	0xF6,0xF7,0xF4,0x33,0x08,0xFB,0xFC,0xFD,
	0xFE,0xFB,0x33,0x60,0xA8,0x28,0x31,0xA2,	0xA0,0xC1,0x83,0x25,0x4A,0xA4,0x78,0x31,
	0x43,0x84,0xC3,0x87,0x10,0x23,0x3A,0x9C,	0x11,0xA2,0xA2,0xC5,0x8B,0x18,0x2B,0xD2,
	0x00,0xC1,0xB1,0xA3,0xC7,0x8F,0x1C,0x67,	0x7C,0x18,0x49,0xB2,0xA4,0xC9,0x91,0x33,
	0x3C,0xA8,0x5C,0xC9,0xB2,0xA5,0xCA,0x19,	0x1A,0x62,0xCA,0x9C,0x49,0x33,0xE6,0x0C,
	0x0A,0x38,0x73,0xEA,0xDC,0x89,0x73,0x06,	0x84,0x9F,0x40,0x83,0x0A,0xFD,0x49,0x83,
	0x81,0xD1,0xA3,0x48,0x93,0x1A,0x9D,0x71,	0xA0,0xA9,0xD3,0xA7,0x50,0x9B,0xCE,0x30,
	0x40,0xB5,0xAA,0xD5,0xAB,0x54,0x67,0x14,	0xD8,0xCA,0xB5,0xAB,0xD7,0xAD,0x33,0x08,
	0x88,0x1D,0x4B,0xB6,0xAC,0xD8,0x19,0x03,	0xD2,0xAA,0x5D,0xCB,0x36,0x2D,0x0D,0x01,
	0xFE,0x70,0xE3,0xCA,0x9D,0x0B,0x77,0x46,	0x80,0xBB,0x78,0xF3,0xEA,0xBD,0x3B,0x03,
	0x80,0xDF,0xBF,0x80,0x03,0xFB,0x0D,0x38,	0xF0,0xA0,0xE1,0x11,0x09,0x17,0x36,0x94,
	0xC8,0xF8,0x21,0xC5,0x8C,0x90,0x2D,0x6E,	0x04,0x49,0xB9,0xA3,0xC8,0x93,0x98,0x49,
	0xA6,0x74,0xC9,0x79,0x25,0xCC,0x9A,0xA0,	0x65,0xDE,0xE4,0x49,0x3A,0xA7,0xCF,0xA1,
	0xA8,0x81,0x16,0x55,0xCA,0xFA,0x28,0xD3,	0xA8,0xB0,0x9D,0x4E,0xC5,0x4A,0xBB,0xAA,
	0xD6,0xAF,0xB8,0xB9,0x86,0x35,0xCB,0x7B,	0x2C,0xDA,0xB6,0xC0,0xD5,0xBE,0xA5,0x4B,
	0x3C,0xAE,0xDD,0xBD,0xC8,0xF1,0xF6,0x15,	0xCC,0xFC,0xEF,0x0C,0x1C,0x3D,0x80,0x04,
	0x99,0x4E,0xBD,0xBA,0xF4,0x1E,0x39,0x66,	0xFC,0xD8,0xCE,0xBD,0xBB,0xF7,0x1F,0x3E,
	0x66,0xF8,0x18,0x4F,0xBE,0xBC,0xF9,0xF1,	0x34,0x7A,0xA8,0x5F,0xCF,0xBE,0xBD,0xFA,
	0x19,0x3C,0xE2,0xCB,0x9F,0x4F,0x3F,0xFE,	0x8C,0x1D,0xF8,0xF3,0xEB,0xDF,0x8F,0x7F,
	0x86,0x8E,0xFF,0x00,0x06,0x28,0xE0,0x7F,	0x33,0xDC,0x60,0xE0,0x81,0x08,0x26,0x68,
	0xE0,0x0C,0x36,0x34,0xE8,0xE0,0x83,0x10,	0x36,0x48,0x43,0x0D,0x14,0x56,0x68,0xE1,
	0x85,0x14,0xCE,0x20,0xC3,0x86,0x1C,0x76,	0xE8,0xE1,0x86,0x33,0xB8,0x20,0xE2,0x88,
	0x24,0x96,0x28,0xE2,0x0C,0x2D,0xA4,0xA8,	0xE2,0x8A,0x2C,0xA6,0x38,0x03,0x0B,0x30,
	0xC6,0x28,0xE3,0x8C,0x30,0xCE,0xB0,0xC2,	0x8D,0x38,0xE6,0xA8,0xE3,0x8D,0x34,0xA0,
	0xE0,0xE3,0x8F,0x40,0x06,0xE9,0xE3,0x0C,	0x27,0x14,0x69,0xE4,0x91,0x48,0x16,0x0B,
	0x39,0x83,0x09,0x4C,0x36,0xE9,0xE4,0x93,	0x4C,0x06,0x02,0x00,0x3B
};
#endif //_MGINCORE_RES
